# vim:fileencoding=utf-8:foldmethod=marker
{ pkgs, username, ... }:
{
  imports = [
    ./hardware-configuration.nix
    ./home.nix
  ];

  boot.loader = {
    systemd-boot.enable = true;
    efi.canTouchEfiVariables = true;
  };

  age.secrets.rustypaste = {
    file = ../../secrets/rustypaste.age;
    mode = "440";
    group = "wheel";
  };

  #: Power Consumption {{{
  services.logind = {
    powerKey = "hibernate";
  };
  #: }}}

  xdg = {
    portal.enable = true;
    mime.enable = true;
  };

  modules = {
    system.networking = {
      wifi.enable = true;
      bluetooth.enable = true;
    };

    services = {
      nysh.enable = true;
      tailscale = {
        enable = true;
        tags = [ "client" ];
      };
      rsync-backup = {
        enable = true;
        sources = [
          "/home/ny/Downloads"
          "/home/ny/notes"
        ];
        target = {
          location = "backup";
          type = "rsyncd";
          host = "shan";
        };
        incremental.enable = true;
      };
    };

    media.enableAll = true;
  };

  services = {
    displayManager.sddm.enable = true;
    dbus.enable = true;
    pipewire.enable = true;
    # Necessary for Nautilus to display trash, DVDs and for gnome-disk-utility to show file systems
    gvfs.enable = true;
    gnome.gnome-keyring.enable = true;
  };

  programs = {
    dconf.enable = true;
    steam.enable = true;
    fish.enable = true;
    firefox.enable = true;
    thunderbird.enable = true;
    sway.enable = true;
    hyprland.enable = true;
  };

  security.polkit.enable = true;

  users = {
    defaultUserShell = pkgs.fish;
    users.${username} = {
      isNormalUser = true;
      createHome = true;
      extraGroups = [
        "networkmanager"
        "wheel"
        "audio"
        "libvirtd" # VM OPs
        "dialout" # Necessary for serial port interactions
      ];
    };
  };

  age.identityPaths = [
    "/etc/ssh/ssh_host_ed25519_key"
  ];

  programs.gnupg.agent = {
    enable = true;
    enableSSHSupport = true;
  };

  environment.systemPackages = with pkgs; [
    fish
    wireguard-tools
    git
    htop
    eza
    bat
    nfs-utils
  ];

  services.rpcbind.enable = true; # necessary for nfs

  system.stateVersion = "24.05";
}
